@@ -7,6 +7,7 @@
 // specific language governing permissions and limitations relating to use of the SAFE Network
 // Software.
 
+use crate::client::Address;
 use crate::section_info::Error as TargetSectionError;
 use serde::{Deserialize, Serialize};
 use sn_data_types::PublicKey;
@@ -53,8 +54,8 @@ pub enum Error {
     #[error("Serialization error: {0}")]
     Serialization(String),
     /// Requested data not found
-    #[error("Requested data not found")]
-    NoSuchData,
+    #[error("Requested data not found: {0:?}")]
+    DataNotFound(Address),
     /// No history found for PublicKey
     #[error("No history found for PublicKey: {0}")]
     NoHistoryForPublicKey(sn_data_types::PublicKey),
